@@ -1,5 +1,5 @@
 
-from pcbnewTransition import KICAD_VERSION, isV6
+from pcbnewTransition import KICAD_VERSION, isV6, isV7
 from kikit.common import KIKIT_LIB
 import sys
 import click
@@ -16,7 +16,7 @@ def drcapi():
     """
     Return version of the DRC API
     """
-    if isV6():
+    if isV6() or isV7():
         print("1")
     else:
         print("0")
@@ -38,4 +38,4 @@ def cli():
 
 cli.add_command(kicadversion)
 cli.add_command(drcapi)
-cli.add_command(lib)
\ No newline at end of file
+cli.add_command(lib)
